@@ -657,7 +657,13 @@ static void stop_stack (card_p card) {
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
-static int relocate_and_load (card_p cp, void * image, unsigned image_len, unsigned long * ptx, unsigned long * prx) {
+static int relocate_and_load (
+	card_p		cp,
+	void *		image,
+	unsigned	image_len,
+	unsigned long *	ptx, 
+	unsigned long *	prx
+) {
 	int		res;
 	int		size, align;
 	unsigned	usize;
@@ -735,18 +741,26 @@ static void start_ware (card_p cp) {
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
-static void * get_mapped_addr_from_tm_ptr (card_p cp, unsigned long X) {
-	unsigned long	res;
+void * map_addr_from_tm_ptr (card_p cp, unsigned long X) {
+	unsigned long	res = X;
 	
-	res = PEEK (cp->mem_base + (X - (unsigned long) cp->addr_sdram));
 	assert (res > cp->addr_sdram);
 	res -= cp->addr_sdram;
 	assert (res < cp->len_sdram);
 	res += (unsigned) cp->mem_base;
-
-	log (__FUNCTION__ "() : TM 0x%08x = mapped host 0x%08x\n", X, res);
+	log (__FUNCTION__ "() : TM 0x%08x mapped to 0x%08x\n", X, res);
 	return (void *) res;
-} /* get_mapped_addr_from_tm_ptr */
+} /* deref_map_addr_from_tm_ptr */
+
+/*---------------------------------------------------------------------------*\
+\*---------------------------------------------------------------------------*/
+void * deref_map_addr_from_tm_ptr (card_p cp, unsigned long X) {
+	unsigned long	res;
+	
+	res = PEEK (cp->mem_base + (X - (unsigned long) cp->addr_sdram));
+	log (__FUNCTION__ "() : TM 0x%08x = %08x\n", X, res);
+	return map_addr_from_tm_ptr (cp, res);
+} /* deref_map_addr_from_tm_ptr */
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
@@ -820,11 +834,10 @@ int __entry load_ware (struct capi_ctr * ctrl, capiloaddata * ware) {
 	}
 	log ("Firmware response time: %u ms.\n", 100 * count);
 	POKE (cp->io_base + CONFIG_DATA, 0);
-	
 	assert (tx_info == NULL);
 	assert (rx_info == NULL);
-	tx_info = (xfer_base_p) get_mapped_addr_from_tm_ptr (cp, utx);
-	rx_info = (xfer_base_p) get_mapped_addr_from_tm_ptr (cp, urx);
+	tx_info = (xfer_base_p) deref_map_addr_from_tm_ptr (cp, utx);
+	rx_info = (xfer_base_p) deref_map_addr_from_tm_ptr (cp, urx);
 	load_flag = 1;
 	start_stack (cp);	
 	if (ctrl_context[0].ctrl != NULL) {
